@@ -128,6 +128,7 @@ OC.L10N.register(
     "Archive path" : "Archiver le chemin d'accès",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "Entrer le chemin d’accès d’un dossier dans vos fichiers où les fichiers favoris doivent être stockés.",
     "Backups" : "Sauvegardes",
+    "Enable bookmarks backups" : "Activer la sauvegarde des favoris",
     "Client apps" : "Applications clientes",
     "Also check out the collection of client apps that integrate with this app: " : "Découvrez également une gamme d'applications client qui s'intègrent à cette application : ",
     "Install web app on device" : "Installer l’application web sur l’appareil",
@@ -136,6 +137,7 @@ OC.L10N.register(
     "Bookmarklet" : "Favelets",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "Faites glisser ce lien vers les favoris de votre navigateur et cliquez dessus pour ajouter rapidement un favori à une page Web.",
     "Add to {instanceName}" : "Ajouter à {instanceName}",
+    "Backup path" : "Dossier de sauvegarde",
     "Please select \"Add to home screen\" in your browser menu" : "Veuillez sélectionner \"Ajouter à l'écran d'accueil\" dans le menu de votre navigateur",
     "Title" : "Titre",
     "Link" : "Lien",
@@ -148,7 +150,6 @@ OC.L10N.register(
     "Archived file" : "Fichier archivé",
     "Open file" : "Ouvrir le fichier",
     "Open file location" : "Ouvrir l’emplacement du fichier",
-    "Projects" : "Projets",
     "Created {time} ago" : "Créé il y a {time}",
     "Created on {date}" : "Créé le {date}",
     "Owner" : "Propriétaire",
@@ -164,13 +165,14 @@ OC.L10N.register(
     "Allow editing" : "Autoriser la modification",
     "Allow resharing" : "Autoriser le repartage",
     "Remove share" : "Supprimer le partage",
+    "Projects" : "Projets",
     "Link copied" : "Lien copié",
     "Privacy" : "Vie privée",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "Bookmarks tentera d'accéder aux pages Web que vous enregistrez pour ajouter automatiquement des informations à leur sujet.",
     "Enable accessing and collecting information from the web pages you add" : "Activer l'accès et la collecte d'informations à partir des pages Web que vous enregistrez",
     "Performance" : "Performance",
     "In an installation with a lot of users it may be useful to restrict the number of bookmarks per account." : "Dans une installation avec un grand nombre d'utilisateurs, il peut être utile de restreindre le nombre de favoris par compte.",
-    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Nombre maximum de signets autorisés par compte (0 pour aucune limite ; par défaut, aucune limite)",
+    "Maximum allowed number of bookmarks per account. (0 for no limit; default is no limit)" : "Nombre maximum de signets autorisés par compte (0 pour aucune limite ; par défaut, aucune limite)",
     "Previews" : "Prévisualisations",
     "In order to display real screenshots of your bookmarked websites, Bookmarks can use third-party services to generate previews." : "Afin d'afficher de vrais captures d'écrans de vos sites favoris, Favoris peut utiliser des services tiers pour générer ces aperçus",
     "Screeenly" : "Screeenly",
@@ -212,6 +214,7 @@ OC.L10N.register(
     "Failed to load setting {key}" : "Échec du chargement du paramètre {key}",
     "Failed to update share {shareId}" : "Impossible de mettre à jour le partage {shareId}",
     "Failed to delete share {shareId}" : "Impossible de supprimer le partage {shareId}",
+    "Create bookmarks for mentioned links" : "Créer des marque-pages pour les liens mentionnés",
     "No links found in this message" : "Aucun lien trouvé dans ce message",
     "Bookmarks feed" : "Flux de suivi"
 },
