@@ -42,10 +42,12 @@ OC.L10N.register(
     "Select bookmark" : "Seleziona segnalibro",
     "Details" : "Dettagli",
     "Rename" : "Rinomina",
+    "Copy link" : "Copia colleg.",
     "Move" : "Sposta",
     "Add to folders" : "Aggiungi a cartelle",
     "Delete" : "Elimina",
     "Do you really want to delete this bookmark?" : "Vuoi davvero eliminare questo segnalibro?",
+    "Link copied to clipboard" : "Collegamento copiato negli appunti",
     "Content pending" : "Contenuti in sospeso",
     "This content is being downloaded for offline use. Please check back later." : "Questo contenuto è in scaricamento per l'utilizzo non in linea. Torna più tardi.",
     "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "I segnalibri per file sul web come foto o PDF saranno automaticamente salvati nei tuoi file di Nextcloud, in modo che tu possa trovarli anche quando il collegamento non sarà disponibile.",
@@ -83,8 +85,6 @@ OC.L10N.register(
     "_%n bookmark_::_%n bookmarks_" : ["%n segnalibro","%n segnalibri","%n segnalibri"],
     "_%n folder_::_%n folders_" : ["1%n cartella","%n cartelle","%n cartelle"],
     "Welcome to Bookmarks" : "Benvenuto in segnalibri",
-    "This app allows you to manage links to your favorite places on the web." : "Questa app ti permette di gestire i link ai tuoi luoghi preferiti sul web.",
-    "Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Organizza i tuoi segnalibri in cartelle, etichettali e condividili con gli altri! L'app verifica regolarmente la disponibilità di tutti i tuoi collegamenti e visualizza i collegamenti non disponibili Se aggiungi un collegamento a un file sul Web, il file verrà scaricato automaticamente nei tuoi file Nextcloud. Puoi anche importare i segnalibri esportati da altri servizi o sincronizzare direttamente i segnalibri da tutti i tuoi browser con questa app.",
     "Add a bookmark" : "Aggiungi un segnalibro",
     "Import bookmarks" : "Importa segnalibri",
     "Sync with your browser" : "Sincronizza con il tuo browser",
@@ -146,7 +146,6 @@ OC.L10N.register(
     "Archived file" : "File archiviato",
     "Open file" : "Apri file",
     "Open file location" : "Apri percorso file",
-    "Projects" : "Progetti",
     "Created {time} ago" : "Creato {time} fa",
     "Created on {date}" : "Creato il {date}",
     "Owner" : "Proprietario",
@@ -154,7 +153,6 @@ OC.L10N.register(
     "Select a user or group" : "Seleziona un utente o gruppo",
     "Share link" : "Condividi collegamento",
     "Reading allowed" : "Lettura consentita",
-    "Copy link" : "Copia colleg.",
     "Copy RSS feed" : "Copia fonte RSS",
     "Delete link" : "Elimina collegamento",
     "Create public link" : "Crea collegamento pubblico",
@@ -163,6 +161,7 @@ OC.L10N.register(
     "Allow editing" : "Consenti la modifica",
     "Allow resharing" : "Consenti la ri-condivisione",
     "Remove share" : "Rimuovi condivisione",
+    "Projects" : "Progetti",
     "Link copied" : "Collegamento copiato",
     "Privacy" : "Riservatezza",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "Segnalibri proverà ad accedere alle pagine web che hai aggiunto per integrare automaticamente informazioni su di esse.",
