@@ -89,8 +89,6 @@ OC.L10N.register(
     "_%n bookmark_::_%n bookmarks_" : ["%n zaznamek","%n zaznamka","%n zaznamki","%n zaznamkov"],
     "_%n folder_::_%n folders_" : ["%n mapa","%n mapi","%n mape","%n map"],
     "Welcome to Bookmarks" : "Dobrodošli med Zaznamki",
-    "This app allows you to manage links to your favorite places on the web." : "Program omogoča upravljanje povezav do priljubljenih mest na spletu.",
-    "Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "Omogoča razvrščanje zaznamkov v mape, označevanje z oznakami in izmenjavo z drugimi uporabniki! Program sproti preverja razpoložljivost vpisanih povezav in prikaže nedostopne. Povezave do datotek na spletu sprožijo samodejen prenos v oblak Nextcloud. Prav tako je mogoče uvoziti zaznamke iz drugih storitev in neposredno usklajevanje zaznamkov iz vseh brskalnikov.",
     "Add a bookmark" : "Dodaj zaznamek",
     "Import bookmarks" : "Uvozi zaznamke",
     "Sync with your browser" : "Uskladi z brskalnikom",
@@ -157,7 +155,6 @@ OC.L10N.register(
     "Archived file" : "Arhivirane datoteke",
     "Open file" : "Odpri datoteko",
     "Open file location" : "Odpri mesto datoteke",
-    "Projects" : "Projekti",
     "Created {time} ago" : "Ustvarjeno {time}",
     "Created on {date}" : "Ustvarjeno {date}",
     "Owner" : "Lastnik",
@@ -173,6 +170,7 @@ OC.L10N.register(
     "Allow editing" : "Dovoli urejanje",
     "Allow resharing" : "Dovoli nadaljnje omogočanje souporabe",
     "Remove share" : "Odstrani souporabo",
+    "Projects" : "Projekti",
     "Link copied" : "Povezava je kopirana",
     "Privacy" : "Zasebnost",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "Program poskuša pridobiti podatke dodanih spletnih strani in jih dodati v opis povezave.",
