@@ -6,7 +6,10 @@ OC.L10N.register(
     "Move" : "Move",
     "Delete" : "நீக்குக",
     "New" : "புதிய",
+    "Delete folder" : "கோப்பை அழிக்க",
     "Cancel" : "இரத்து செய்க",
+    "Shared with you" : "Shared with you",
+    "Files" : "கோப்புகள்",
     "Import" : "இறக்குமதி",
     "Export" : "ஏற்றுமதி",
     "Title" : "தலைப்பு",
