@@ -15,6 +15,7 @@ OC.L10N.register(
     "Share folder" : "Спільний доступ до каталогу",
     "New" : "Створити",
     "New folder" : "Новий каталог",
+    "Sort by last modified" : "Впорядкувати за останніми змінами",
     "Add a bookmark" : "Додати закладку",
     "Rename folder" : "Перейменувати каталог",
     "Delete folder" : "Вилучити каталог",
@@ -30,16 +31,17 @@ OC.L10N.register(
     "Tags" : "Позначки",
     "Notes" : "Нотатки",
     "Open file" : "Відкрити файл",
-    "Projects" : "Проєкти",
     "Owner" : "Власник",
-    "Sharing" : "Поділитись",
+    "Sharing" : "Поділитися",
     "Select a user or group" : "Виберіть користувача або групу",
-    "Share link" : "Поширити посилання",
+    "Share link" : "Поділитися посиланням",
     "Allow editing" : "Дозволити редагування",
     "Allow resharing" : "Можете ділитися",
+    "Projects" : "Проєкти",
     "Link copied" : "Посилання скопійовано",
     "Privacy" : "Конфіденційність",
     "Failed to save settings" : "Неможливо зберегти налаштування",
+    "Failed to load settings" : "Не вдалося завантажити налаштування",
     "This URL is already bookmarked! Overwrite?" : "Цей URL вже є в закладках! Перезаписати?",
     "Folder" : "Каталог",
     "Save" : "Зберегти"
