@@ -28,7 +28,7 @@ OC.L10N.register(
     "No file provided for import" : "未提供导入文件",
     "Unsupported file type for import" : "不支持导入的文件类型",
     "Bookmarks Backups" : "书签备份",
-    "Bookmarks shared by %s" : "书签共享者 %s",
+    "Bookmarks shared by %s" : "由 %s 共享的书签",
     "Frequent bookmarks" : "常用书签",
     "Recent bookmarks" : "近期书签",
     "Bookmark" : "书签",
@@ -39,6 +39,7 @@ OC.L10N.register(
     "Create bookmark" : "创建书签",
     "Takes a link and adds it to your collection of bookmarks." : "获取一个链接并将其添加到您的书签中。",
     "A Bookmark manager for Nextcloud" : "适用于 Nextcloud 的书签管理",
+    "- 📂 Sort bookmarks into folders\n- 🏷 Add tags and personal notes\n- 🔍 Full-text search\n- 📲 Synchronize with all your browsers and devices\n- 👪 Share bookmarks with other users and publicly\n- ☠ Find broken links\n- ⚛ Generate RSS feeds of your collections\n- 📔 Read archived versions of your links in case they are depublished\n- 💬 Create new bookmarks directly from within Nextcloud Talk\n- 💼 Built-in Dashboard widgets for frequent and recent links\n\nRequirements:\n - PHP v7.4+\n - PHP extensions:\n   - intl: *\n   - mbstring: *\n - when using MySQL, use at least v8.0" : "- 📂 以文件夹分类书签\n- 🏷 添加标签和个人记录\n- 🔍 全文检索\n- 📲 与您所有的浏览器和设备同步\n- 👪 与其他用户或公开分享书签\n- ☠ 查找失效的链接\n- ⚛ 生成您收藏列表的 RSS 订阅源\n- 📔 查阅链接的历史存档版本，以防他们被不再发布\n- 💬 直接在 Nextcloud Talk 中创建新的书签\n- 💼 用于频繁和最近链接的内置的仪表盘组件\n\n要求:\n - PHP v7.4+\n - PHP 扩展:\n   - intl: *\n   - mbstring: *\n - 如果使用 MySQL, 至少使用 v8.0",
     "Enter new title" : "输入新标题",
     "Select bookmark" : "选择书签",
     "Details" : "详情",
@@ -52,6 +53,9 @@ OC.L10N.register(
     "Content pending" : "内容待定",
     "This content is being downloaded for offline use. Please check back later." : "此内容正被下载以供离线使用。请稍后再来查看。 ",
     "Bookmarks to files on the web like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "网络上的文件，类似照片或 PDF 等的书签会被自动保存到你的Nextcloud 文件中，这样即使链接的文件消失，你仍然可以找到它们。",
+    "Bookmarked links are checked regularly and the ones that cannot be reached are listed here." : "已添加书签的链接会定期检查，无法访问的链接会显示在这里",
+    "You can share bookmark folders with others. All folders shared with you are listed here." : "您可以与其他人分享书签文件夹。所有与您分享的文件夹会显示在这里。",
+    "One bookmark can be in multiple folders at once. Updating it will update all copies. All duplicated bookmarks are listed here for convenience." : "一个书签可以同时在多个文件夹中。更新它将会更新所有副本。为了方便起见，这里列出了所有重复的书签。",
     "Open all selected" : "打开所选",
     "Move selection" : "移动选择项",
     "Edit tags of selection" : "编辑选中的标签",
@@ -85,6 +89,7 @@ OC.L10N.register(
     "{folders} folders and {bookmarks} bookmarks" : "{folders} 个文件夹和{bookmarks}枚书签",
     "_%n bookmark_::_%n bookmarks_" : ["%n枚书签"],
     "_%n folder_::_%n folders_" : ["%n个文件夹"],
+    "Welcome to Bookmarks" : "欢迎使用书签",
     "Add a bookmark" : "添加书签",
     "Import bookmarks" : "导入标签",
     "Sync with your browser" : "与你的浏览器同步",
@@ -110,26 +115,35 @@ OC.L10N.register(
     "Recent" : "最近",
     "Shared with you" : "已共享给您",
     "Files" : "文件",
+    "Duplicates" : "重复",
     "Broken links" : "失效的链接",
     "New tag" : "新标签",
     "Search tags" : "搜索标签",
     "Untagged" : "未标记的",
-    "{used} bookmarks of {available} available" : "书签已用{used}/可用 {available}",
+    "{used} bookmarks of {available} available" : "书签已用 {used} / 可用 {available}",
     "No bookmarked files" : "无已添加书签的文件",
     "Bookmarks to files like photos or PDFs will automatically be saved to your Nextcloud files, so you can still find them even when the link goes offline." : "照片或PDF等文件的书签会被自动保存到你的 Nextcloud 文件中 因此即使链接下线，你仍然可以找到它们。",
+    "No broken links" : "没有失效的链接",
+    "No shared folders" : "没有共享的文件夹",
+    "No duplicated bookmarks" : "没有重复的书签",
     "No bookmarks here" : "无书签",
+    "Add bookmarks manually or import bookmarks from a HTML file." : "手动添加书签或从 HTML 文件中导入书签。",
     "Import" : "导入",
     "Export" : "导出",
     "Archive path" : "归档路径",
     "Enter the path of a folder in your Files where bookmarked files should be stored." : "输入一个 Nextcloud File 文件夹的路径，加书签的文件会被存储至该文件夹",
+    "Backups" : "备份",
+    "Enable bookmarks backups" : "启用书签备份",
+    "Enter the path of a folder in your Files where backups will be stored." : "输入一个要存储备份的 Nextcloud File 文件夹的路径。",
     "Client apps" : "客户端应用",
     "Also check out the collection of client apps that integrate with this app: " : "还可以查看与此应用集成的客户端应用集合：",
-    "Install web app on device" : "在设备上安装 web 应用",
+    "Install web app on device" : "在设备上安装 Web 应用",
     "You can install this app on your device home screen to quickly access your bookmarks on your phone. You can easily remove the app from your home screen again, if you don't like it." : "你可以在你的设备主屏幕上安装这个应用程序来快速访问你手机上的书签。如果你不喜欢它，你可以很容易地从主屏幕上删除它。",
     "Install on home screen" : "安装到主屏幕",
     "Bookmarklet" : "小书签",
     "Drag this to your browser bookmarks and click it to quickly bookmark a webpage." : "将此拖到浏览器书签中，并单击它可快速将网页添加为书签。",
     "Add to {instanceName}" : "添加到 {instanceName}",
+    "Backup path" : "备份路径",
     "Please select \"Add to home screen\" in your browser menu" : "请点击浏览器菜单中的“添加到主屏幕”",
     "Title" : "标题",
     "Link" : "链接",
@@ -142,7 +156,6 @@ OC.L10N.register(
     "Archived file" : "已存档的文件",
     "Open file" : "打开文件 ",
     "Open file location" : "打开文件位置 ",
-    "Projects" : "项目",
     "Created {time} ago" : "创建于 {time} 之前",
     "Created on {date}" : "创建于 {date}",
     "Owner" : "拥有者",
@@ -158,6 +171,7 @@ OC.L10N.register(
     "Allow editing" : "允许编辑",
     "Allow resharing" : "允许重新分享",
     "Remove share" : "移除共享",
+    "Projects" : "项目",
     "Link copied" : "已复制链接",
     "Privacy" : "隐私",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "书签应用将访问您添加的网页以自动获取关于它们的信息。",
@@ -176,6 +190,8 @@ OC.L10N.register(
     "ScreenshotMachine" : "ScreenshotMachine",
     "ScreenshotMachine API key" : "ScreenshotMachine API key",
     "Pageres CLI" : "Pageres CLI",
+    "Simply install the Pageres CLI on your server and Bookmarks will find it. You can still add additional ENV vars to be fed to pageres, e.g. as indicated in the placeholder:" : "只要在您的服务器上安装 Pageres CLI，书签应用就会找到它。您也可以为 pageres 添加额外的 ENV 变量，如在占位符中所示：",
+    "Pageres ENV variables" : "Pageres ENV 变量",
     "Failed to save settings" : "无法保存设置",
     "Failed to load settings" : "无法加载设置",
     "This URL is already bookmarked! Overwrite?" : "此链接已加入书签！是否覆盖？",
@@ -185,8 +201,10 @@ OC.L10N.register(
     "Root Folder" : "根目录",
     "Save" : "保存",
     "Network access is disabled by default. Go to administrator settings for the bookmarks app to allow fetching previews and favicons." : "网络访问默认关闭。进入书签应用的管理员设置，允许获取预览和书签图标。 ",
+    "Link to a bookmark folder" : "连接到书签文件夹",
     "Failed to count unavailable bookmarks" : "无法计算不可用的书签",
     "Failed to count archived bookmarks" : "无法计算归档的书签",
+    "Failed to count duplicated bookmarks" : "无法计算重复的书签",
     "Failed to load bookmark" : "载入标签失败",
     "Failed to find existing bookmark" : "无法找到已有书签",
     "Failed to create bookmark" : "无法创建书签",
@@ -204,6 +222,8 @@ OC.L10N.register(
     "Failed to load setting {key}" : "加载设置{key}失败",
     "Failed to update share {shareId}" : "无法更新共享{shareId}",
     "Failed to delete share {shareId}" : "无法删除共享{shareId}",
+    "Create bookmarks for mentioned links" : "为提到的链接创建书签",
+    "No links found in this message" : "消息中没有找到链接",
     "Bookmarks feed" : "书签订阅源"
 },
 "nplurals=1; plural=0;");
