@@ -90,8 +90,6 @@ OC.L10N.register(
     "_%n bookmark_::_%n bookmarks_" : ["%n 書籤"],
     "_%n folder_::_%n folders_" : ["%n 個資料夾"],
     "Welcome to Bookmarks" : "歡迎來到 Bookmarks",
-    "This app allows you to manage links to your favorite places on the web." : "這個應用程式允許您管理指向您在網絡上最喜歡的地方的連結。",
-    "Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "將您的書籤分類到資料夾中，用標籤標記它們並與他人分享！該應用程式會定期檢查您所有連結的可用性並顯示不可用的連結。如果您在網絡上添加指向檔案的鏈接，該檔案將自動下載到您的 Nextcloud 檔案中。您還可以導入從其他服務導出的書籤，或直接將所有瀏覽器中的書籤與此應用程式同步。",
     "Add a bookmark" : "新增書籤",
     "Import bookmarks" : "匯入書籤",
     "Sync with your browser" : "與瀏覽器同步",
@@ -158,7 +156,6 @@ OC.L10N.register(
     "Archived file" : "已封存檔案",
     "Open file" : "開啟檔案",
     "Open file location" : "開啟檔案位置",
-    "Projects" : "專案項目",
     "Created {time} ago" : "在 {time} 前創建",
     "Created on {date}" : "創建於 {date} ",
     "Owner" : "擁有者",
@@ -174,6 +171,7 @@ OC.L10N.register(
     "Allow editing" : "允許編輯",
     "Allow resharing" : "允許轉貼分享",
     "Remove share" : "移除分享",
+    "Projects" : "專案項目",
     "Link copied" : "連結已複製",
     "Privacy" : "私隱",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "書籤將嘗試存取您添加的網頁，以自動添加有關它們的信息。",
