@@ -90,8 +90,6 @@ OC.L10N.register(
     "_%n bookmark_::_%n bookmarks_" : ["%n 書籤"],
     "_%n folder_::_%n folders_" : ["%n 資料夾"],
     "Welcome to Bookmarks" : "歡迎使用書籤",
-    "This app allows you to manage links to your favorite places on the web." : "此應用程式讓您可以管理指向您在網路上最喜歡的地方的連結。",
-    "Sort your bookmarks into folders, label them with tags and share them with others! The app will regularly check all your links for availability and display unavailable links. If you add a link to a file on the web, the file will be automatically downloaded to your Nextcloud Files. You can also import bookmarks exported from other services or directly sync bookmarks from all your browsers with this app." : "將您的書籤分類至資料夾中，用標籤標記它們並與其他人分享！應用程式會定期檢查您所有連結的可用性，並顯示無法使用的連結。若您在網路上新增指向檔案的連結，該檔案將會自動下載到您的 Nextcloud Files 中。您也可以匯入從其他服務匯出的書籤，或是直接將所有瀏覽器中的書籤與此應用程式同步。",
     "Add a bookmark" : "新增書籤",
     "Import bookmarks" : "匯入書籤",
     "Sync with your browser" : "與您的瀏覽器同步",
@@ -158,7 +156,6 @@ OC.L10N.register(
     "Archived file" : "已封存的檔案",
     "Open file" : "開啟檔案",
     "Open file location" : "開啟檔案位置",
-    "Projects" : "專案",
     "Created {time} ago" : "建立於 {time} 前",
     "Created on {date}" : "建立於 {date}",
     "Owner" : "擁有者",
@@ -174,6 +171,7 @@ OC.L10N.register(
     "Allow editing" : "允許編輯",
     "Allow resharing" : "允許轉分享",
     "Remove share" : "移除分享",
+    "Projects" : "專案",
     "Link copied" : "連結已複製",
     "Privacy" : "隱私",
     "Bookmarks will try to access web pages that you add to automatically add information about them." : "書籤將會嘗試存取您新增的網頁，以自動新增關於它們的資訊。",
