@@ -13,8 +13,6 @@ use OCA\Bookmarks\Db\Bookmark;
 use OCA\Bookmarks\Db\BookmarkMapper;
 use OCA\Bookmarks\Service\BookmarkPreviewer;
 use OCA\Bookmarks\Service\CrawlService;
-use OCP\Http\Client\IClient;
-use OCP\Http\Client\IClientService;
 use OCP\IConfig;
 
 class CrawlJob extends TimedJob {
@@ -29,22 +27,10 @@ class CrawlJob extends TimedJob {
 	 * @var IConfig
 	 */
 	private $settings;
-	/**
-	 * @var IClientService
-	 */
-	private $clientService;
-	/**
-	 * @var IClient
-	 */
-	private $client;
 	/**
 	 * @var CrawlService
 	 */
 	private $crawler;
-	/**
-	 * @var ITimeFactory
-	 */
-	private $timeFactory;
 
 	public function __construct(
 		IConfig $settings, BookmarkMapper $bookmarkMapper, CrawlService $crawler, ITimeFactory $timeFactory
