@@ -13,15 +13,20 @@ use OCP\AppFramework\Db\Entity;
  * Class Folder
  *
  * @package OCA\Bookmarks\Db
- * @method getTitle()
+ * @method string getTitle()
  * @method setTitle(string $title)
- * @method getUserId
+ * @method string getUserId()
  * @method setUserId(string $userId)
  */
 class Folder extends Entity {
+	/**
+	 * @var string
+	 */
 	protected $title;
+	/**
+	 * @var string
+	 */
 	protected $userId;
-	protected $index;
 
 	public static $columns = ['id', 'title', 'user_id'];
 
@@ -32,6 +37,11 @@ class Folder extends Entity {
 		$this->addType('userId', 'string');
 	}
 
+	/**
+	 * @return array
+	 *
+	 * @psalm-return array{id: int, title: string, userId: string}
+	 */
 	public function toArray(): array {
 		return ['id' => $this->id, 'title' => $this->title, 'userId' => $this->userId];
 	}
